@@ -7,6 +7,7 @@
 #include "SheetBrowser.h"
 #include "BrowserPage.h"
 #include "Application.h"
+#include "ddlog.h"
 
 #include <QPainter>
 #include <QDebug>
@@ -17,46 +18,51 @@
 
 ReadMagnifierManager::ReadMagnifierManager(QWidget *parent) : QThread(parent)
 {
-    qDebug() << "ReadMagnifierManager created";
+    // qCDebug(appLog) << "ReadMagnifierManager created";
     m_parent = parent;
 }
 
 ReadMagnifierManager::~ReadMagnifierManager()
 {
-    qDebug() << "ReadMagnifierManager destroyed";
+    // qCDebug(appLog) << "ReadMagnifierManager destroyed";
     this->wait();
 }
 
 void ReadMagnifierManager::addTask(const MagnifierInfo_t &task)
 {
-    qDebug() << "ReadMagnifierManager::addTask";
+    qCDebug(appLog) << "ReadMagnifierManager::addTask";
     m_tTasklst << task;
 
     if (!this->isRunning()) {
-        qInfo() << "Starting ReadMagnifierManager thread";
+        qCInfo(appLog) << "Starting ReadMagnifierManager thread";
         this->start();
     }
+    qCDebug(appLog) << "ReadMagnifierManager::addTask() - Add task completed";
 }
 
 void ReadMagnifierManager::run()
 {
+    qCDebug(appLog) << "ReadMagnifierManager::run() - Starting thread run loop";
     while (m_tTasklst.size() > 0 && m_parent->isVisible()) {
+        // qCDebug(appLog) << "ReadMagnifierManager::run() - Processing task, queue size:" << m_tTasklst.size();
         MagnifierInfo_t task = m_tTasklst.last();
         m_tTasklst.clear();
 
         if (task.page) {
+            // qCDebug(appLog) << "ReadMagnifierManager::run() - Getting image from page";
             const QImage &image = task.page->getImagePoint(task.scaleFactor, task.mousePos);
             QMetaObject::invokeMethod(task.target, task.slotFun.toStdString().c_str(), Qt::QueuedConnection, Q_ARG(const MagnifierInfo_t &, task), Q_ARG(const QImage &, image));
         }
 
         msleep(100);
     }
+    qCDebug(appLog) << "ReadMagnifierManager::run() - Thread run loop completed";
 }
 
 BrowserMagniFier::BrowserMagniFier(SheetBrowser *parent)
     : QLabel(parent)
 {
-    qDebug() << "BrowserMagniFier created";
+    qCDebug(appLog) << "BrowserMagniFier created";
     m_readManager = new ReadMagnifierManager(this);
 
     m_brwoser = parent;
@@ -72,25 +78,28 @@ BrowserMagniFier::BrowserMagniFier(SheetBrowser *parent)
     resize(244, 244);
 
     show();
+    qCDebug(appLog) << "BrowserMagniFier::BrowserMagniFier() - Constructor completed";
 }
 
 BrowserMagniFier::~BrowserMagniFier()
 {
-    qDebug() << "BrowserMagniFier destroyed";
+    // qCDebug(appLog) << "BrowserMagniFier destroyed";
     m_readManager->wait();
 }
 
 void BrowserMagniFier::updateImage()
 {
-    qDebug() << "BrowserMagniFier::updateImage";
+    // qCDebug(appLog) << "BrowserMagniFier::updateImage";
     QPointF point = m_lastScenePoint;
 
     BrowserPage *page = m_brwoser->getBrowserPageForPoint(point);
 
     if (page) {
+        // qCDebug(appLog) << "BrowserMagniFier::updateImage() - Found page, getting current image";
         const QImage &image = page->getCurImagePoint(point);
         setMagniFierImage(image);
     } else {
+        // qCDebug(appLog) << "BrowserMagniFier::updateImage() - No page found, setting empty image";
         setMagniFierImage(QImage());
     }
 
@@ -109,11 +118,12 @@ void BrowserMagniFier::updateImage()
     m_readManager->addTask(task);
 
     m_lastPoint = point.toPoint();
+    // qCDebug(appLog) << "BrowserMagniFier::updateImage() - Image update completed";
 }
 
 void BrowserMagniFier::showMagnigierImage(QPoint mousePos, QPoint magnifierPos, double scaleFactor)
 {
-    qDebug() << "BrowserMagniFier::showMagnigierImage at" << mousePos << "with scale" << scaleFactor;
+    // qCDebug(appLog) << "BrowserMagniFier::showMagnigierImage at" << mousePos << "with scale" << scaleFactor;
     scaleFactor += 2;
 
     m_lastScenePoint = mousePos;
@@ -123,10 +133,12 @@ void BrowserMagniFier::showMagnigierImage(QPoint mousePos, QPoint magnifierPos,
     BrowserPage *page = m_brwoser->getBrowserPageForPoint(ponitf);
 
     if (page) {
+        // qCDebug(appLog) << "BrowserMagniFier::showMagnigierImage() - Found page, getting current image";
         const QImage &image = page->getCurImagePoint(ponitf);
 
         setMagniFierImage(image);
     } else {
+        // qCDebug(appLog) << "BrowserMagniFier::showMagnigierImage() - No page found, setting empty image";
         setMagniFierImage(QImage());
     }
 
@@ -149,17 +161,22 @@ void BrowserMagniFier::showMagnigierImage(QPoint mousePos, QPoint magnifierPos,
     m_lastPoint = ponitf.toPoint();
 
     m_lastScaleFactor = scaleFactor;
+    // qCDebug(appLog) << "BrowserMagniFier::showMagnigierImage() - Show magnifier image completed";
 }
 
 void BrowserMagniFier::onUpdateMagnifierImage(const MagnifierInfo_t &task, const QImage &image)
 {
-    qDebug() << "BrowserMagniFier::onUpdateMagnifierImage";
-    if (task.mousePos == m_lastPoint && qFuzzyCompare(task.scaleFactor, m_lastScaleFactor))
+    // qCDebug(appLog) << "BrowserMagniFier::onUpdateMagnifierImage";
+    if (task.mousePos == m_lastPoint && qFuzzyCompare(task.scaleFactor, m_lastScaleFactor)) {
+        // qCDebug(appLog) << "BrowserMagniFier::onUpdateMagnifierImage() - Task matches current state, setting image";
         setMagniFierImage(image);
+    }
+    // qCDebug(appLog) << "BrowserMagniFier::onUpdateMagnifierImage() - Update magnifier image completed";
 }
 
 void BrowserMagniFier::setMagniFierImage(const QImage &image)
 {
+    // qCDebug(appLog) << "BrowserMagniFier::setMagniFierImage() - Starting set magnifier image";
     QPixmap pix(static_cast<int>(this->width() * dApp->devicePixelRatio()), static_cast<int>(this->height() * dApp->devicePixelRatio()));
 
     pix.fill(Qt::transparent);
@@ -177,6 +194,7 @@ void BrowserMagniFier::setMagniFierImage(const QImage &image)
     painter.setClipPath(clippath);
 
     if (!image.isNull()) {
+        // qCDebug(appLog) << "BrowserMagniFier::setMagniFierImage() - Drawing valid image";
         QImage im = image;
 
         pix.setDevicePixelRatio(1);
@@ -185,6 +203,7 @@ void BrowserMagniFier::setMagniFierImage(const QImage &image)
 
         painter.drawImage(0, 0, im.scaled(static_cast<int>(240 * dApp->devicePixelRatio()), static_cast<int>(240 * dApp->devicePixelRatio()), Qt::KeepAspectRatio, Qt::SmoothTransformation));
     } else {
+        // qCDebug(appLog) << "BrowserMagniFier::setMagniFierImage() - Drawing white background for null image";
         painter.fillRect(this->rect(), Qt::white);
     }
     painter.restore();
@@ -194,4 +213,5 @@ void BrowserMagniFier::setMagniFierImage(const QImage &image)
     pix.setDevicePixelRatio(dApp->devicePixelRatio());
 
     setPixmap(pix);
+    // qCDebug(appLog) << "BrowserMagniFier::setMagniFierImage() - Set magnifier image completed";
 }
