@@ -9,6 +9,7 @@
 #include "DocSheet.h"
 #include "SheetRenderer.h"
 #include "SideBarImageViewModel.h"
+#include "ddlog.h"
 
 #include <QTime>
 #include <QDebug>
@@ -21,7 +22,7 @@ bool PageRenderThread::s_quitForever = false;
 
 PageRenderThread::PageRenderThread(QObject *parent) : QThread(parent)
 {
-    qDebug() << "PageRenderThread created";
+    qCDebug(appLog) << "PageRenderThread created";
     qRegisterMetaType<deepin_reader::Document *>("deepin_reader::Document *");
     qRegisterMetaType<QList<deepin_reader::Word>>("QList<deepin_reader::Word>");
     qRegisterMetaType<QList<deepin_reader::Annotation *>>("QList<deepin_reader::Annotation *>");
@@ -43,23 +44,29 @@ PageRenderThread::PageRenderThread(QObject *parent) : QThread(parent)
     connect(this, &PageRenderThread::sigDocPageAnnotationTaskFinished, this, &PageRenderThread::onDocPageAnnotationTaskFinished, Qt::QueuedConnection);
     connect(this, &PageRenderThread::sigDocPageThumbnailTaskFinished, this, &PageRenderThread::onDocPageThumbnailTask, Qt::QueuedConnection);
     connect(this, &PageRenderThread::sigDocOpenTask, this, &PageRenderThread::onDocOpenTask, Qt::QueuedConnection);
+    qCDebug(appLog) << "PageRenderThread::PageRenderThread() - Constructor completed";
 }
 
 PageRenderThread::~PageRenderThread()
 {
-    qDebug() << "PageRenderThread destroyed";
+    // qCDebug(appLog) << "PageRenderThread destroyed";
     m_quit = true;
     wait();
+    // qCDebug(appLog) << "PageRenderThread::~PageRenderThread() - Destructor completed";
 }
 
 bool PageRenderThread::clearImageTasks(DocSheet *sheet, BrowserPage *page, int pixmapId)
 {
-    if (nullptr == page)
+    // qCDebug(appLog) << "PageRenderThread::clearImageTasks() - Starting clear image tasks";
+    if (nullptr == page) {
+        // qCDebug(appLog) << "PageRenderThread::clearImageTasks() - Page is null, returning true";
         return true;
+    }
 
     PageRenderThread *instance  = PageRenderThread::instance();
 
     if (nullptr == instance) {
+        // qCDebug(appLog) << "PageRenderThread::clearImageTasks() - Instance is null, returning false";
         return false;
     }
 
@@ -73,6 +80,7 @@ bool PageRenderThread::clearImageTasks(DocSheet *sheet, BrowserPage *page, int p
             if (instance->m_pageNormalImageTasks[i].page == page &&
                     instance->m_pageNormalImageTasks[i].sheet == sheet &&
                     (instance->m_pageNormalImageTasks[i].pixmapId != pixmapId || -1 == pixmapId)) {
+                // qCDebug(appLog) << "PageRenderThread::clearImageTasks() - Removing normal image task at index:" << i;
                 instance->m_pageNormalImageTasks.removeAt(i);
                 exist = true;
                 break;
@@ -92,6 +100,7 @@ bool PageRenderThread::clearImageTasks(DocSheet *sheet, BrowserPage *page, int p
             if (instance->m_pageSliceImageTasks[i].page == page &&
                     instance->m_pageSliceImageTasks[i].sheet == sheet &&
                     (instance->m_pageSliceImageTasks[i].pixmapId != pixmapId || -1 == pixmapId)) {
+                // qCDebug(appLog) << "PageRenderThread::clearImageTasks() - Removing slice image task at index:" << i;
                 instance->m_pageSliceImageTasks.removeAt(i);
                 exist = true;
                 break;
@@ -111,6 +120,7 @@ bool PageRenderThread::clearImageTasks(DocSheet *sheet, BrowserPage *page, int p
             if (instance->m_pageBigImageTasks[i].page == page &&
                     instance->m_pageBigImageTasks[i].sheet == sheet &&
                     (instance->m_pageBigImageTasks[i].pixmapId != pixmapId || -1 == pixmapId)) {
+                // qCDebug(appLog) << "PageRenderThread::clearImageTasks() - Removing big image task at index:" << i;
                 instance->m_pageBigImageTasks.removeAt(i);
                 exist = true;
                 break;
@@ -119,37 +129,41 @@ bool PageRenderThread::clearImageTasks(DocSheet *sheet, BrowserPage *page, int p
     }
 
     instance->m_pageBigImageMutex.unlock();
-
+    // qCDebug(appLog) << "PageRenderThread::clearImageTasks() - Clear image tasks completed";
     return true;
 }
 
 void PageRenderThread::appendTask(DocPageNormalImageTask task)
 {
+    // qCDebug(appLog) << "PageRenderThread::appendTask() - Starting append normal image task";
     PageRenderThread *instance  = PageRenderThread::instance();
 
     if (nullptr == instance) {
-        qWarning() << "PageRenderThread instance is null";
+        qCWarning(appLog) << "PageRenderThread instance is null";
         return;
     }
 
     instance->m_pageNormalImageMutex.lock();
 
     instance->m_pageNormalImageTasks.append(task);
-    qDebug() << "Append normal image task, page:" << task.page->itemIndex();
+    // qCDebug(appLog) << "Append normal image task, page:" << task.page->itemIndex();
 
     instance->m_pageNormalImageMutex.unlock();
 
     if (!instance->isRunning()) {
-        qDebug() << "Starting render thread";
+        // qCDebug(appLog) << "Starting render thread";
         instance->start();
     }
+    // qCDebug(appLog) << "PageRenderThread::appendTask() - Append normal image task completed";
 }
 
 void PageRenderThread::appendTask(DocPageSliceImageTask task)
 {
+    // qCDebug(appLog) << "PageRenderThread::appendTask() - Starting append slice image task";
     PageRenderThread *instance  = PageRenderThread::instance();
 
     if (nullptr == instance) {
+        // qCDebug(appLog) << "PageRenderThread::appendTask() - Instance is null, returning";
         return;
     }
 
@@ -159,15 +173,20 @@ void PageRenderThread::appendTask(DocPageSliceImageTask task)
 
     instance->m_pageSliceImageMutex.unlock();
 
-    if (!instance->isRunning())
+    if (!instance->isRunning()) {
+        // qCDebug(appLog) << "Starting render thread";
         instance->start();
+    }
+    // qCDebug(appLog) << "PageRenderThread::appendTask() - Append slice image task completed";
 }
 
 void PageRenderThread::appendTask(DocPageBigImageTask task)
 {
+    // qCDebug(appLog) << "PageRenderThread::appendTask() - Starting append big image task";
     PageRenderThread *instance  = PageRenderThread::instance();
 
     if (nullptr == instance) {
+        // qCDebug(appLog) << "PageRenderThread::appendTask() - Instance is null, returning";
         return;
     }
 
@@ -177,15 +196,20 @@ void PageRenderThread::appendTask(DocPageBigImageTask task)
 
     instance->m_pageBigImageMutex.unlock();
 
-    if (!instance->isRunning())
+    if (!instance->isRunning()) {
+        // qCDebug(appLog) << "Starting render thread";
         instance->start();
+    }
+    // qCDebug(appLog) << "PageRenderThread::appendTask() - Append big image task completed";
 }
 
 void PageRenderThread::appendTask(DocPageWordTask task)
 {
+    // qCDebug(appLog) << "PageRenderThread::appendTask() - Starting append word task";
     PageRenderThread *instance  = PageRenderThread::instance();
 
     if (nullptr == instance) {
+        // qCDebug(appLog) << "PageRenderThread::appendTask() - Instance is null, returning";
         return;
     }
 
@@ -195,15 +219,20 @@ void PageRenderThread::appendTask(DocPageWordTask task)
 
     instance->m_pageWordMutex.unlock();
 
-    if (!instance->isRunning())
+    if (!instance->isRunning()) {
+        // qCDebug(appLog) << "Starting render thread";
         instance->start();
+    }
+    // qCDebug(appLog) << "PageRenderThread::appendTask() - Append word task completed";
 }
 
 void PageRenderThread::appendTask(DocPageAnnotationTask task)
 {
+    // qCDebug(appLog) << "PageRenderThread::appendTask() - Starting append annotation task";
     PageRenderThread *instance  = PageRenderThread::instance();
 
     if (nullptr == instance) {
+        // qCDebug(appLog) << "PageRenderThread::appendTask() - Instance is null, returning";
         return;
     }
 
@@ -213,15 +242,20 @@ void PageRenderThread::appendTask(DocPageAnnotationTask task)
 
     instance->m_pageAnnotationMutex.unlock();
 
-    if (!instance->isRunning())
+    if (!instance->isRunning()) {
+        // qCDebug(appLog) << "Starting render thread";
         instance->start();
+    }
+    // qCDebug(appLog) << "PageRenderThread::appendTask() - Append annotation task completed";
 }
 
 void PageRenderThread::appendTask(DocPageThumbnailTask task)
 {
+    // qCDebug(appLog) << "PageRenderThread::appendTask() - Starting append thumbnail task";
     PageRenderThread *instance  = PageRenderThread::instance();
 
     if (nullptr == instance) {
+        // qCDebug(appLog) << "PageRenderThread::appendTask() - Instance is null, returning";
         return;
     }
 
@@ -237,9 +271,11 @@ void PageRenderThread::appendTask(DocPageThumbnailTask task)
 
 void PageRenderThread::appendTask(DocOpenTask task)
 {
+    // qCDebug(appLog) << "PageRenderThread::appendTask() - Starting append open task";
     PageRenderThread *instance  = PageRenderThread::instance();
 
     if (nullptr == instance) {
+        // qCDebug(appLog) << "PageRenderThread::appendTask() - Instance is null, returning";
         return;
     }
 
@@ -255,9 +291,11 @@ void PageRenderThread::appendTask(DocOpenTask task)
 
 void PageRenderThread::appendTask(DocCloseTask task)
 {
+    // qCDebug(appLog) << "PageRenderThread::appendTask() - Starting append close task";
     PageRenderThread *instance  = PageRenderThread::instance();
 
     if (nullptr == instance) {
+        // qCDebug(appLog) << "PageRenderThread::appendTask() - Instance is null, returning";
         return;
     }
 
@@ -267,19 +305,20 @@ void PageRenderThread::appendTask(DocCloseTask task)
 
     instance->m_closeMutex.unlock();
 
-    qDebug() << "当前任务线程运行状态: " << instance->isRunning();
+    // qCDebug(appLog) << "当前任务线程运行状态: " << instance->isRunning();
     if (!instance->isRunning())
         instance->start();
+    // qCDebug(appLog) << "PageRenderThread::appendTask() - Append close task completed";
 }
 
 void PageRenderThread::run()
 {
     m_quit = false;
-    qDebug() << "====开始执行任务====";
+    qCDebug(appLog) << "====开始执行任务====";
 
     while (!m_quit) {
         if (!hasNextTask()) {
-            //qDebug() << "任务池中不存在任务！等待添加任务";
+            //qCDebug(appLog) << "任务池中不存在任务！等待添加任务";
             msleep(100);
             continue;
         }
@@ -383,11 +422,12 @@ void PageRenderThread::run()
     //处理关闭所有文档
     while (execNextDocCloseTask())
     {}
-    qDebug() << "====结束执行任务====";
+    qCDebug(appLog) << "====结束执行任务====";
 }
 
 bool PageRenderThread::hasNextTask()
 {
+    // qCDebug(appLog) << "PageRenderThread::hasNextTask() - Starting has next task";
     QMutexLocker pageNormalImageLocker(&m_pageNormalImageMutex);
     QMutexLocker pageSliceImageLocker(&m_pageSliceImageMutex);
     QMutexLocker pageBigImageLocker(&m_pageBigImageMutex);
@@ -402,6 +442,7 @@ bool PageRenderThread::hasNextTask()
 
 bool PageRenderThread::popNextDocPageNormalImageTask(DocPageNormalImageTask &task)
 {
+    // qCDebug(appLog) << "PageRenderThread::popNextDocPageNormalImageTask() - Starting pop next normal image task";
     QMutexLocker locker(&m_pageNormalImageMutex);
 
     if (m_pageNormalImageTasks.count() <= 0)
@@ -411,11 +452,13 @@ bool PageRenderThread::popNextDocPageNormalImageTask(DocPageNormalImageTask &tas
 
     m_pageNormalImageTasks.removeLast();
 
+    // qCDebug(appLog) << "PageRenderThread::popNextDocPageNormalImageTask() - Pop next normal image task completed";
     return true;
 }
 
 bool PageRenderThread::popNextDocPageSliceImageTask(DocPageSliceImageTask &task)
 {
+    // qCDebug(appLog) << "PageRenderThread::popNextDocPageSliceImageTask() - Starting pop next slice image task";
     QMutexLocker locker(&m_pageSliceImageMutex);
 
     if (m_pageSliceImageTasks.count() <= 0)
@@ -425,11 +468,13 @@ bool PageRenderThread::popNextDocPageSliceImageTask(DocPageSliceImageTask &task)
 
     m_pageSliceImageTasks.removeLast();
 
+    // qCDebug(appLog) << "PageRenderThread::popNextDocPageSliceImageTask() - Pop next slice image task completed";
     return true;
 }
 
 bool PageRenderThread::popNextDocPageBigImageTask(DocPageBigImageTask &task)
 {
+    // qCDebug(appLog) << "PageRenderThread::popNextDocPageBigImageTask() - Starting pop next big image task";
     QMutexLocker locker(&m_pageBigImageMutex);
 
     if (m_pageBigImageTasks.count() <= 0)
@@ -439,11 +484,13 @@ bool PageRenderThread::popNextDocPageBigImageTask(DocPageBigImageTask &task)
 
     m_pageBigImageTasks.removeLast();
 
+    // qCDebug(appLog) << "PageRenderThread::popNextDocPageBigImageTask() - Pop next big image task completed";
     return true;
 }
 
 bool PageRenderThread::popNextDocPageWordTask(DocPageWordTask &task)
 {
+    // qCDebug(appLog) << "PageRenderThread::popNextDocPageWordTask() - Starting pop next word task";
     QMutexLocker locker(&m_pageWordMutex);
 
     if (m_pageWordTasks.count() <= 0)
@@ -453,11 +500,13 @@ bool PageRenderThread::popNextDocPageWordTask(DocPageWordTask &task)
 
     m_pageWordTasks.removeAt(0);
 
+    // qCDebug(appLog) << "PageRenderThread::popNextDocPageWordTask() - Pop next word task completed";
     return true;
 }
 
 bool PageRenderThread::popNextDocPageAnnotationTask(DocPageAnnotationTask &task)
 {
+    // qCDebug(appLog) << "PageRenderThread::popNextDocPageAnnotationTask() - Starting pop next annotation task";
     QMutexLocker locker(&m_pageAnnotationMutex);
 
     if (m_pageAnnotationTasks.count() <= 0)
@@ -467,11 +516,13 @@ bool PageRenderThread::popNextDocPageAnnotationTask(DocPageAnnotationTask &task)
 
     m_pageAnnotationTasks.removeAt(0);
 
+    // qCDebug(appLog) << "PageRenderThread::popNextDocPageAnnotationTask() - Pop next annotation task completed";
     return true;
 }
 
 bool PageRenderThread::popNextDocPageThumbnailTask(DocPageThumbnailTask &task)
 {
+    // qCDebug(appLog) << "PageRenderThread::popNextDocPageThumbnailTask() - Starting pop next thumbnail task";
     QMutexLocker locker(&m_pageThumbnailMutex);
 
     // 优先显示除缩略图外的图片
@@ -486,11 +537,13 @@ bool PageRenderThread::popNextDocPageThumbnailTask(DocPageThumbnailTask &task)
 
     m_pageThumbnailTasks.removeLast();
 
+    // qCDebug(appLog) << "PageRenderThread::popNextDocPageThumbnailTask() - Pop next thumbnail task completed";
     return true;
 }
 
 bool PageRenderThread::popNextDocOpenTask(DocOpenTask &task)
 {
+    // qCDebug(appLog) << "PageRenderThread::popNextDocOpenTask() - Starting pop next open task";
     QMutexLocker locker(&m_openMutex);
 
     if (m_openTasks.count() <= 0)
@@ -500,11 +553,13 @@ bool PageRenderThread::popNextDocOpenTask(DocOpenTask &task)
 
     m_openTasks.removeAt(0);
 
+    // qCDebug(appLog) << "PageRenderThread::popNextDocOpenTask() - Pop next open task completed";
     return true;
 }
 
 bool PageRenderThread::popNextDocCloseTask(DocCloseTask &task)
 {
+    // qCDebug(appLog) << "PageRenderThread::popNextDocCloseTask() - Starting pop next close task";
     QMutexLocker locker(&m_closeMutex);
 
     if (m_closeTasks.count() <= 0)
@@ -514,36 +569,37 @@ bool PageRenderThread::popNextDocCloseTask(DocCloseTask &task)
 
     m_closeTasks.removeAt(0);
 
+    // qCDebug(appLog) << "PageRenderThread::popNextDocCloseTask() - Pop next close task completed";
     return true;
 }
 
 bool PageRenderThread::execNextDocPageNormalImageTask()
 {
-    qDebug() << "Executing normal image task...";
+    qCDebug(appLog) << "Executing normal image task...";
 
     if (m_quit) {
-        qDebug() << "Render thread quitting, abort task";
+        qCDebug(appLog) << "Render thread quitting, abort task";
         return false;
     }
 
     DocPageNormalImageTask task;
 
     if (!popNextDocPageNormalImageTask(task)) {
-        qDebug() << "No normal image tasks in queue";
+        qCDebug(appLog) << "No normal image tasks in queue";
         return false;
     }
 
     if (!DocSheet::existSheet(task.sheet)) {
-        qWarning() << "Sheet no longer exists, skip task";
+        qCWarning(appLog) << "Sheet no longer exists, skip task";
         return true;
     }
 
     QImage image = task.sheet->getImage(task.page->itemIndex(), task.rect.width(), task.rect.height());
 
     if (image.isNull()) {
-        qWarning() << "Failed to get image for page:" << task.page->itemIndex();
+        qCWarning(appLog) << "Failed to get image for page:" << task.page->itemIndex();
     } else {
-        qDebug() << "Image rendered successfully for page:" << task.page->itemIndex();
+        qCDebug(appLog) << "Image rendered successfully for page:" << task.page->itemIndex();
         emit sigDocPageNormalImageTaskFinished(task, QPixmap::fromImage(image));
     }
 
@@ -552,22 +608,22 @@ bool PageRenderThread::execNextDocPageNormalImageTask()
 
 bool PageRenderThread::execNextDocPageSliceImageTask()
 {
-    qDebug() << "正在执行取切片任务...";
+    qCDebug(appLog) << "正在执行取切片任务...";
     if (m_quit) {
-        qDebug() << "取切片任务已结束";
+        qCDebug(appLog) << "取切片任务已结束";
         return false;
     }
 
     DocPageSliceImageTask task;
 
     if (!popNextDocPageSliceImageTask(task)) {
-        qDebug() << "任务池不存在取切片任务，已结束";
+        qCDebug(appLog) << "任务池不存在取切片任务，已结束";
         return false;
     }
 
 
     if (!DocSheet::existSheet(task.sheet)) {
-        qDebug() << "文档不存在，取切片任务已结束";
+        qCDebug(appLog) << "文档不存在，取切片任务已结束";
         return true;
     }
 
@@ -576,27 +632,27 @@ bool PageRenderThread::execNextDocPageSliceImageTask()
     if (!image.isNull())
         emit sigDocPageSliceImageTaskFinished(task, QPixmap::fromImage(image));
 
-    qDebug() << "执行取切片文字任务已完成";
+    qCDebug(appLog) << "执行取切片文字任务已完成";
     return true;
 }
 
 bool PageRenderThread::execNextDocPageWordTask()
 {
-    qDebug() << "正在执行取页码文字任务...";
+    qCDebug(appLog) << "正在执行取页码文字任务...";
     if (m_quit) {
-        qDebug() << "取页码文字任务已结束";
+        qCDebug(appLog) << "取页码文字任务已结束";
         return false;
     }
 
     DocPageWordTask task;
 
     if (!popNextDocPageWordTask(task)) {
-        qDebug() << "任务池不存在取页码文字任务，已结束";
+        qCDebug(appLog) << "任务池不存在取页码文字任务，已结束";
         return false;
     }
 
     if (!DocSheet::existSheet(task.sheet)) {
-        qDebug() << "文档不存在，取页码文字任务已结束";
+        qCDebug(appLog) << "文档不存在，取页码文字任务已结束";
         return true;
     }
 
@@ -605,27 +661,27 @@ bool PageRenderThread::execNextDocPageWordTask()
 
     emit sigDocPageWordTaskFinished(task, words);
 
-    qDebug() << "执行取页码文字任务已完成";
+    qCDebug(appLog) << "执行取页码文字任务已完成";
     return true;
 }
 
 bool PageRenderThread::execNextDocPageAnnotationTask()
 {
-    qDebug() << "正在执行取页码注释任务...";
+    qCDebug(appLog) << "正在执行取页码注释任务...";
     if (m_quit) {
-        qDebug() << "取页码注释任务已结束";
+        qCDebug(appLog) << "取页码注释任务已结束";
         return false;
     }
 
     DocPageAnnotationTask task;
 
     if (!popNextDocPageAnnotationTask(task)) {
-        qDebug() << "任务池不存在取页码注释任务，已结束";
+        qCDebug(appLog) << "任务池不存在取页码注释任务，已结束";
         return false;
     }
 
     if (!DocSheet::existSheet(task.sheet)) {
-        qDebug() << "文档不存在，取页码注释任务已结束";
+        qCDebug(appLog) << "文档不存在，取页码注释任务已结束";
         return true;
     }
 
@@ -633,27 +689,27 @@ bool PageRenderThread::execNextDocPageAnnotationTask()
 
     emit sigDocPageAnnotationTaskFinished(task, annots);
 
-    qDebug() << "执行取页码注释任务已完成";
+    qCDebug(appLog) << "执行取页码注释任务已完成";
     return true;
 }
 
 bool PageRenderThread::execNextDocPageThumbnailTask()
 {
-    qDebug() << "正在执行缩略图任务...";
+    qCDebug(appLog) << "正在执行缩略图任务...";
     if (m_quit) {
-        qDebug() << "缩略图任务已结束";
+        qCDebug(appLog) << "缩略图任务已结束";
         return false;
     }
 
     DocPageThumbnailTask task;
 
     if (!popNextDocPageThumbnailTask(task)) {
-        qDebug() << "任务池不存在缩略图任务，已结束";
+        qCDebug(appLog) << "任务池不存在缩略图任务，已结束";
         return false;
     }
 
     if (!DocSheet::existSheet(task.sheet)) {
-        qDebug() << "文档不存在，缩略图任务已结束";
+        qCDebug(appLog) << "文档不存在，缩略图任务已结束";
         return true;
     }
 
@@ -661,27 +717,27 @@ bool PageRenderThread::execNextDocPageThumbnailTask()
 
     if (!image.isNull())
         emit sigDocPageThumbnailTaskFinished(task, QPixmap::fromImage(image));
-    qDebug() << "执行缩略图任务已完成";
+    qCDebug(appLog) << "执行缩略图任务已完成";
     return true;
 }
 
 bool PageRenderThread::execNextDocOpenTask()
 {
-    qDebug() << "正在执行文档打开任务...";
+    qCDebug(appLog) << "正在执行文档打开任务...";
     if (m_quit) {
-        qDebug() << "文档打开任务已结束";
+        qCDebug(appLog) << "文档打开任务已结束";
         return false;//false 为不用再继续循环调用
     }
 
     DocOpenTask task;
 
     if (!popNextDocOpenTask(task)) {
-        qDebug() << "任务池不存在文档打开任务，已结束";
+        qCDebug(appLog) << "任务池不存在文档打开任务，已结束";
         return false;//false 为不用再继续循环调用
     }
 
     if (!DocSheet::existSheet(task.sheet)) {
-        qDebug() << "文档不存在，文档打开任务已结束";
+        qCDebug(appLog) << "文档不存在，文档打开任务已结束";
         return true;
     }
 
@@ -691,7 +747,7 @@ bool PageRenderThread::execNextDocOpenTask()
 
     deepin_reader::Document::Error error = deepin_reader::Document::NoError;
 
-    qDebug() << "PageRenderThread::execNextDocOpenTask" <<  task.sheet->convertedFileDir();
+    qCDebug(appLog) << "PageRenderThread::execNextDocOpenTask" <<  task.sheet->convertedFileDir();
     deepin_reader::Document *document = deepin_reader::DocumentFactory::getDocument(task.sheet->fileType(), filePath, task.sheet->convertedFileDir(), task.password, &(task.sheet->m_process), error);
 
     if (nullptr == document) {
@@ -723,18 +779,18 @@ bool PageRenderThread::execNextDocOpenTask()
     }
     PERF_PRINT_END("POINT-03", "");
     PERF_PRINT_END("POINT-05", QString("filename=%1,filesize=%2").arg(QFileInfo(filePath).fileName()).arg(QFileInfo(filePath).size()));
-    qDebug() << "文档打开任务已完成";
+    qCDebug(appLog) << "文档打开任务已完成";
 
     return true;
 }
 
 bool PageRenderThread::execNextDocCloseTask()
 {
-    qDebug() << "正在执行文档关闭任务...";
+    qCDebug(appLog) << "正在执行文档关闭任务...";
     DocCloseTask task;
 
     if (!popNextDocCloseTask(task)) {
-        qDebug() << "不存在关闭任务，已结束";
+        qCDebug(appLog) << "不存在关闭任务，已结束";
         return false;   //false 为不用再继续循环调用
     }
 
@@ -742,81 +798,100 @@ bool PageRenderThread::execNextDocCloseTask()
 
     delete task.document;
 
-    qDebug() << "文档关闭任务已完成";
+    qCDebug(appLog) << "文档关闭任务已完成";
     return true;
 }
 
 void PageRenderThread::onDocPageNormalImageTaskFinished(DocPageNormalImageTask task, QPixmap pixmap)
 {
+    // qCDebug(appLog) << "PageRenderThread::onDocPageNormalImageTaskFinished() - Starting on doc page normal image task finished";
     if (DocSheet::existSheet(task.sheet)) {
         task.page->handleRenderFinished(task.pixmapId, pixmap);
     }
+    // qCDebug(appLog) << "PageRenderThread::onDocPageNormalImageTaskFinished() - On doc page normal image task finished completed";
 }
 
 void PageRenderThread::onDocPageSliceImageTaskFinished(DocPageSliceImageTask task, QPixmap pixmap)
 {
+    // qCDebug(appLog) << "PageRenderThread::onDocPageSliceImageTaskFinished() - Starting on doc page slice image task finished";
     if (DocSheet::existSheet(task.sheet)) {
         task.page->handleRenderFinished(task.pixmapId, pixmap, task.slice);
     }
+    // qCDebug(appLog) << "PageRenderThread::onDocPageSliceImageTaskFinished() - On doc page slice image task finished completed";
 }
 
 void PageRenderThread::onDocPageBigImageTaskFinished(DocPageBigImageTask task, QPixmap pixmap)
 {
+    // qCDebug(appLog) << "PageRenderThread::onDocPageBigImageTaskFinished() - Starting on doc page big image task finished";
     if (DocSheet::existSheet(task.sheet)) {
         task.page->handleRenderFinished(task.pixmapId, pixmap);
     }
+    // qCDebug(appLog) << "PageRenderThread::onDocPageBigImageTaskFinished() - On doc page big image task finished completed";
 }
 
 void PageRenderThread::onDocPageWordTaskFinished(DocPageWordTask task, QList<deepin_reader::Word> words)
 {
+    // qCDebug(appLog) << "PageRenderThread::onDocPageWordTaskFinished() - Starting on doc page word task finished";
     if (DocSheet::existSheet(task.sheet)) {
         task.page->handleWordLoaded(words);
     }
+    // qCDebug(appLog) << "PageRenderThread::onDocPageWordTaskFinished() - On doc page word task finished completed";
 }
 
 void PageRenderThread::onDocPageAnnotationTaskFinished(DocPageAnnotationTask task, QList<deepin_reader::Annotation *> annots)
 {
+    // qCDebug(appLog) << "PageRenderThread::onDocPageAnnotationTaskFinished() - Starting on doc page annotation task finished";
     if (DocSheet::existSheet(task.sheet)) {
         task.page->handleAnnotationLoaded(annots);
     }
+    // qCDebug(appLog) << "PageRenderThread::onDocPageAnnotationTaskFinished() - On doc page annotation task finished completed";
 }
 
 void PageRenderThread::onDocPageThumbnailTask(DocPageThumbnailTask task, QPixmap pixmap)
 {
+    // qCDebug(appLog) << "PageRenderThread::onDocPageThumbnailTask() - Starting on doc page thumbnail task";
     if (DocSheet::existSheet(task.sheet)) {
         task.model->handleRenderThumbnail(task.index, pixmap);
     }
+    // qCDebug(appLog) << "PageRenderThread::onDocPageThumbnailTask() - On doc page thumbnail task completed";
 }
 
 void PageRenderThread::onDocOpenTask(DocOpenTask task, deepin_reader::Document::Error error, deepin_reader::Document *document, QList<deepin_reader::Page *> pages)
 {
+    // qCDebug(appLog) << "PageRenderThread::onDocOpenTask() - Starting on doc open task";
     if (DocSheet::existSheet(task.sheet)) {
         task.renderer->handleOpened(error, document, pages);
     }
+    // qCDebug(appLog) << "PageRenderThread::onDocOpenTask() - On doc open task completed";
 }
 
 void PageRenderThread::destroyForever()
 {
+    // qCDebug(appLog) << "PageRenderThread::destroyForever() - Starting destroy forever";
     s_quitForever = true;
 
     if (nullptr != s_instance) {
+        // qCDebug(appLog) << "PageRenderThread::destroyForever() - Instance is not null, quitting instance";
         s_instance->m_quit = true;
         s_instance->wait();
         delete s_instance;
     }
+    // qCDebug(appLog) << "PageRenderThread::destroyForever() - Destroy forever completed";
 }
 
 PageRenderThread *PageRenderThread::instance()
 {
+    // qCDebug(appLog) << "PageRenderThread::instance() - Starting instance";
     if (s_quitForever) {
-        qDebug() << "Render thread permanently quit";
+        // qCDebug(appLog) << "Render thread permanently quit";
         return nullptr;
     }
 
     if (nullptr == s_instance) {
-        qDebug() << "Creating new render thread instance";
+        // qCDebug(appLog) << "Creating new render thread instance";
         s_instance = new PageRenderThread;
     }
 
+    // qCDebug(appLog) << "PageRenderThread::instance() - Instance created";
     return s_instance;
 }
