@@ -6,6 +6,7 @@
 #include "PageSearchThread.h"
 #include "BrowserPage.h"
 #include "SheetRenderer.h"
+#include "ddlog.h"
 
 #include <QRectF>
 #include <QDebug>
@@ -15,47 +16,47 @@ QMap<QChar, QChar> PageSearchThread::m_cjktokangximap;
 
 PageSearchThread::PageSearchThread(QObject *parent) : QThread(parent)
 {
-    qDebug() << "PageSearchThread created";
+    qCDebug(appLog) << "PageSearchThread created";
 }
 
 PageSearchThread::~PageSearchThread()
 {
-    qDebug() << "PageSearchThread destroyed";
+    qCDebug(appLog) << "PageSearchThread destroyed";
     m_quit = true;
     this->wait();
 }
 
 void PageSearchThread::startSearch(DocSheet *sheet, QString text)
 {
-    qDebug() << "Starting search for:" << text;
+    qCDebug(appLog) << "Starting search for:" << text;
     stopSearch();
     m_quit = false;
     m_startIndex = 0;
     m_sheet = sheet;
     m_searchText = text;
     start();
-    qDebug() << "Search thread started";
+    qCDebug(appLog) << "Search thread started";
 }
 
 void PageSearchThread::stopSearch()
 {
-    qDebug() << "Stopping search";
+    qCDebug(appLog) << "Stopping search";
     m_quit = true;
     this->wait();
     m_sheet = nullptr;
-    qDebug() << "Search stopped";
+    qCDebug(appLog) << "Search stopped";
 }
 
 void PageSearchThread::run()
 {
     if (nullptr == m_sheet) {
-        qWarning() << "Search run failed: sheet is null";
+        qCWarning(appLog) << "Search run failed: sheet is null";
         return;
     }
 
     initCJKtoKangxi();
 
-    qDebug() << "Searching through" << m_sheet->pageCount() << "pages";
+    qCDebug(appLog) << "Searching through" << m_sheet->pageCount() << "pages";
     bool isSearchResultNotEmpty = false; // 没有搜索结果
     int size = m_sheet->pageCount();
     QString searchTextKangxi = m_searchText;
@@ -67,7 +68,7 @@ void PageSearchThread::run()
 
     for (int index = 0; index < size; index++) {
         if (m_quit) {
-            qDebug() << "Search cancelled";
+            qCDebug(appLog) << "Search cancelled";
             return;
         }
 
@@ -84,10 +85,10 @@ void PageSearchThread::run()
         bool hasWord = searchres.setctionsFillText(getText);
         //
         if (hasWord) {
-            qDebug() << "Found matches on page" << index + 1;
+            qCDebug(appLog) << "Found matches on page" << index + 1;
             if (!isSearchResultNotEmpty) {
                 isSearchResultNotEmpty = true;
-                qDebug() << "First search result found";
+                qCDebug(appLog) << "First search result found";
                 // 只要搜索到结果就emit该信号
                 emit sigSearchResultNotEmpty();
             }
@@ -104,7 +105,7 @@ void PageSearchThread::initCJKtoKangxi()
 
     QFile file(":/CJK2Kangxi.dict");
     if (!file.open(QIODevice::ReadOnly)) {
-        qWarning() << "Failed to open CJK dictionary:" << file.errorString();
+        qCWarning(appLog) << "Failed to open CJK dictionary:" << file.errorString();
         return;
     }
 
