@@ -8,6 +8,7 @@
 #include "SideBarImageViewModel.h"
 #include "Application.h"
 #include "MsgHeader.h"
+#include "ddlog.h"
 
 #include <QScroller>
 #include <QScrollBar>
@@ -18,7 +19,7 @@ SideBarImageListView::SideBarImageListView(DocSheet *sheet, QWidget *parent)
     : DListView(parent)
     , m_docSheet(sheet)
 {
-    qDebug() << "SideBarImageListView created for document:" << (sheet ? sheet->filePath() : "null");
+    qCDebug(appLog) << "SideBarImageListView created for document:" << (sheet ? sheet->filePath() : "null");
     initControl();
     setAutoScroll(false);
     setProperty("adaptScale", 1.0);
@@ -33,21 +34,23 @@ SideBarImageListView::SideBarImageListView(DocSheet *sheet, QWidget *parent)
     setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);
 
     QScroller::grabGesture(this, QScroller::TouchGesture);//滑动
-    qDebug() << "Enabled touch gesture scrolling";
+    qCDebug(appLog) << "Enabled touch gesture scrolling";
 
     connect(verticalScrollBar(), &QScrollBar::sliderPressed, this, &SideBarImageListView::onRemoveThumbnailListSlideGesture);
     connect(verticalScrollBar(), &QScrollBar::sliderReleased, this, &SideBarImageListView::onSetThumbnailListSlideGesture);
-    qDebug() << "Connected scrollbar signals";
+    qCDebug(appLog) << "Connected scrollbar signals";
 }
 
 
 void SideBarImageListView::initControl()
 {
+    qCDebug(appLog) << "SideBarImageListView::initControl start";
     m_pBookMarkMenu = nullptr;
     m_pNoteMenu = nullptr;
     m_listType = E_SideBar::SIDE_THUMBNIL;
     m_imageModel = new SideBarImageViewModel(m_docSheet, this);
     this->setModel(m_imageModel);
+    qCDebug(appLog) << "SideBarImageListView::initControl end";
 }
 
 SideBarImageViewModel *SideBarImageListView::getImageModel()
@@ -57,27 +60,35 @@ SideBarImageViewModel *SideBarImageListView::getImageModel()
 
 void SideBarImageListView::showMenu()
 {
-    if (!this->currentIndex().isValid())
+    qCDebug(appLog) << "SideBarImageListView::showMenu start";
+    if (!this->currentIndex().isValid()) {
+        qCDebug(appLog) << "Current index not valid, returning";
         return;
+    }
 
     const QRect &visualRect = this->visualRect(this->currentIndex());
     QPoint point = mapToGlobal(QPoint(this->width() / 2 - 4, visualRect.y() + visualRect.height() / 2 - 4));
     if (m_listType == E_SideBar::SIDE_NOTE) {
+        qCDebug(appLog) << "Showing note menu";
         showNoteMenu(point);
     } else if (m_listType == E_SideBar::SIDE_BOOKMARK) {
+        qCDebug(appLog) << "Showing bookmark menu";
         showBookMarkMenu(point);
     }
+    qCDebug(appLog) << "SideBarImageListView::showMenu end";
 }
 
 void SideBarImageListView::setListType(int type)
 {
+    qCDebug(appLog) << "Setting list type to:" << type;
     m_listType = type;
 }
 
 void SideBarImageListView::handleOpenSuccess()
 {
-    qDebug() << "Handling open success for list type:" << m_listType;
+    qCDebug(appLog) << "Handling open success for list type:" << m_listType;
     if (m_listType == E_SideBar::SIDE_THUMBNIL) {
+        qCDebug(appLog) << "Handling open success for thumbnail widget";
         const QSet<int> &pageList = m_docSheet->getBookMarkList();
         for (int pageIndex : pageList) {
             m_imageModel->setBookMarkVisible(pageIndex, true, false);
@@ -89,12 +100,14 @@ void SideBarImageListView::handleOpenSuccess()
             pageSrclst << ImagePageInfo_t(index);
         m_imageModel->initModelLst(pageSrclst);
     } else if (m_listType == E_SideBar::SIDE_BOOKMARK) {
+        qCDebug(appLog) << "Handling open success for bookmark widget";
         const QSet<int> &pageList = m_docSheet->getBookMarkList();
         QList<ImagePageInfo_t> pageSrclst;
         for (int pageIndex : pageList)
             pageSrclst << ImagePageInfo_t(pageIndex);
         m_imageModel->initModelLst(pageSrclst, true);
     } else if (m_listType == E_SideBar::SIDE_NOTE) {
+        qCDebug(appLog) << "Handling open success for notes widget";
         const QList< deepin_reader::Annotation * > &annotationlst = m_docSheet->annotations();
         QList<ImagePageInfo_t> pageSrclst;
         int pagesNum = annotationlst.size();
@@ -116,40 +129,45 @@ void SideBarImageListView::handleOpenSuccess()
 
 void SideBarImageListView::onItemClicked(const QModelIndex &index)
 {
+    // qCDebug(appLog) << "Item clicked at row:" << index.row();
     if (index.isValid()) {
+        // qCDebug(appLog) << "Item clicked at row:" << index.row();
         int pageIndex = m_imageModel->getPageIndexForModelIndex(index.row());
-        qDebug() << "Item clicked at row:" << index.row() << "jumping to page:" << pageIndex;
+        // qCDebug(appLog) << "Item clicked at row:" << index.row() << "jumping to page:" << pageIndex;
         m_docSheet->jumpToIndex(pageIndex);
         emit sigListItemClicked(index.row());
     } else {
-        qWarning() << "Invalid index in onItemClicked";
+        qCWarning(appLog) << "Invalid index in onItemClicked";
     }
 }
 
 void SideBarImageListView::onSetThumbnailListSlideGesture()
 {
+    qCDebug(appLog) << "Setting thumbnail list slide gesture";
     QScroller::grabGesture(this, QScroller::TouchGesture);//缩略图列表滑动
 }
 
 void SideBarImageListView::onRemoveThumbnailListSlideGesture()
 {
+    qCDebug(appLog) << "Removing thumbnail list slide gesture";
     QScroller::grabGesture(this, QScroller::MiddleMouseButtonGesture);//缩略图列表不滑动
 }
 
 bool SideBarImageListView::scrollToIndex(int index, bool scrollTo)
 {
-    qDebug() << "Scrolling to index:" << index << "scrollTo:" << scrollTo;
+    qCDebug(appLog) << "Scrolling to index:" << index << "scrollTo:" << scrollTo;
     const QList<QModelIndex> &indexlst = m_imageModel->getModelIndexForPageIndex(index);
     if (indexlst.size() > 0) {
+        qCDebug(appLog) << "Found model index for page index:" << index;
         const QModelIndex &index = indexlst.first();
         if (scrollTo)
             this->scrollTo(index);
         this->selectionModel()->select(index, QItemSelectionModel::SelectCurrent);
         this->setCurrentIndex(index);
-        qDebug() << "Successfully scrolled to model index:" << index.row();
+        qCDebug(appLog) << "Successfully scrolled to model index:" << index.row();
         return true;
     } else {
-        qWarning() << "No model index found for page index:" << index;
+        qCWarning(appLog) << "No model index found for page index:" << index;
         this->setCurrentIndex(QModelIndex());
         this->clearSelection();
         return false;
@@ -158,53 +176,61 @@ bool SideBarImageListView::scrollToIndex(int index, bool scrollTo)
 
 void SideBarImageListView::scrollToModelInexPage(const QModelIndex &index, bool scrollto)
 {
+    qCDebug(appLog) << "Scrolling to model index:" << index << "scrollto:" << scrollto;
     if (index.isValid()) {
+        qCDebug(appLog) << "Model index is valid";
         this->selectionModel()->select(index, QItemSelectionModel::SelectCurrent);
         this->setCurrentIndex(index);
         if (scrollto) this->scrollTo(index);
     }
+    qCDebug(appLog) << "Scrolling to model index end";
 }
 
 void SideBarImageListView::mousePressEvent(QMouseEvent *event)
 {
+    // qCDebug(appLog) << "SideBarImageListView::mousePressEvent start - button:" << event->button();
     DListView::mousePressEvent(event);
     onItemClicked(this->indexAt(event->pos()));
     //Menu
     if (event->button() == Qt::RightButton) {
+        // qCDebug(appLog) << "Right button pressed, checking for menu";
         const QModelIndex &modelIndex = this->indexAt(event->pos());
         if (modelIndex.isValid()) {
             if (m_listType == E_SideBar::SIDE_NOTE) {
+                // qCDebug(appLog) << "Showing note menu";
                 showNoteMenu(QCursor::pos());
             } else if (m_listType == E_SideBar::SIDE_BOOKMARK) {
+                // qCDebug(appLog) << "Showing bookmark menu";
                 showBookMarkMenu(QCursor::pos());
             }
         }
     }
+    // qCDebug(appLog) << "SideBarImageListView::mousePressEvent end";
 }
 
 void SideBarImageListView::showNoteMenu(const QPoint &point)
 {
-    qDebug() << "Showing note menu at:" << point;
+    qCDebug(appLog) << "Showing note menu at:" << point;
     if (m_pNoteMenu == nullptr) {
-        qDebug() << "Creating new note menu";
+        qCDebug(appLog) << "Creating new note menu";
         m_pNoteMenu = new DMenu(this);
         m_pNoteMenu->setAccessibleName("Menu_Note");
 
         QAction *copyAction = m_pNoteMenu->addAction(tr("Copy"));
         connect(copyAction, &QAction::triggered, [this]() {
-            qDebug() << "Copy note action triggered";
+            qCDebug(appLog) << "Copy note action triggered";
             emit sigListMenuClick(E_NOTE_COPY);
         });
 
         QAction *delAction = m_pNoteMenu->addAction(tr("Remove annotation"));
         connect(delAction, &QAction::triggered, [this]() {
-            qDebug() << "Delete note action triggered";
+            qCDebug(appLog) << "Delete note action triggered";
             emit sigListMenuClick(E_NOTE_DELETE);
         });
 
         QAction *delAllAction = m_pNoteMenu->addAction(tr("Remove all"));
         connect(delAllAction, &QAction::triggered, [this]() {
-            qDebug() << "Delete all notes action triggered";
+            qCDebug(appLog) << "Delete all notes action triggered";
             emit sigListMenuClick(E_NOTE_DELETE_ALL);
         });
     }
@@ -213,6 +239,7 @@ void SideBarImageListView::showNoteMenu(const QPoint &point)
 
 void SideBarImageListView::showBookMarkMenu(const QPoint &point)
 {
+    qCDebug(appLog) << "Showing bookmark menu at:" << point;
     if (m_pBookMarkMenu == nullptr) {
         m_pBookMarkMenu = new DMenu(this);
         m_pBookMarkMenu->setAccessibleName("Menu_BookMark");
@@ -228,30 +255,35 @@ void SideBarImageListView::showBookMarkMenu(const QPoint &point)
         });
     }
     m_pBookMarkMenu->exec(point);
+    qCDebug(appLog) << "Showing bookmark menu end";
 }
 
 int  SideBarImageListView::getModelIndexForPageIndex(int pageIndex)
 {
+    qCDebug(appLog) << "Getting model index for page index:" << pageIndex;
     const QList<QModelIndex> &indexlst = m_imageModel->getModelIndexForPageIndex(pageIndex);
     if (indexlst.size() > 0) {
-        qDebug() << "Found model index:" << indexlst.first().row() << "for page:" << pageIndex;
+        qCDebug(appLog) << "Found model index:" << indexlst.first().row() << "for page:" << pageIndex;
         return indexlst.first().row();
     }
-    qWarning() << "No model index found for page:" << pageIndex;
+    qCWarning(appLog) << "No model index found for page:" << pageIndex;
     return -1;
 }
 
 int  SideBarImageListView::getPageIndexForModelIndex(int row)
 {
+    qCDebug(appLog) << "Getting page index for model index:" << row;
     return m_imageModel->getPageIndexForModelIndex(row);
 }
 
 QModelIndex SideBarImageListView::pageUpIndex()
 {
+    qCDebug(appLog) << "Getting page up index";
     return DListView::moveCursor(QAbstractItemView::MovePageUp, Qt::NoModifier);
 }
 
 QModelIndex SideBarImageListView::pageDownIndex()
 {
+    qCDebug(appLog) << "Getting page down index";
     return DListView::moveCursor(QAbstractItemView::MovePageDown, Qt::NoModifier);
 }
