@@ -7,6 +7,7 @@
 #include "Utils.h"
 #include "DocSheet.h"
 #include "WordWrapLabel.h"
+#include "ddlog.h"
 #include <QDebug>
 
 #include <DFontSizeManager>
@@ -19,7 +20,7 @@ DWIDGET_USE_NAMESPACE
 AttrScrollWidget::AttrScrollWidget(DocSheet *sheet, DWidget *parent)
     : DFrame(parent)
 {
-    qDebug() << "AttrScrollWidget constructor start, sheet:" << sheet;
+    qCDebug(appLog) << "AttrScrollWidget constructor start, sheet:" << sheet;
     setFrameShape(QFrame::NoFrame);
 
     installEventFilter(this);
@@ -58,12 +59,12 @@ AttrScrollWidget::AttrScrollWidget(DocSheet *sheet, DWidget *parent)
     vLayout->addStretch(1);
 
     this->setLayout(vLayout);
-    qDebug() << "AttrScrollWidget constructor end";
+    qCDebug(appLog) << "AttrScrollWidget constructor end";
 }
 
 void AttrScrollWidget::createLabel(QGridLayout *layout, const int &index, const QString &objName, const QString &sData)
 {
-    qDebug() << "Create label for" << objName << "with text data";
+    qCDebug(appLog) << "Create label for" << objName << "with text data";
     DLabel *label = new DLabel(objName, this);
     DFontSizeManager::instance()->bind(label, DFontSizeManager::T8);
     label->setAlignment(Qt::AlignTop);
@@ -86,7 +87,7 @@ void AttrScrollWidget::createLabel(QGridLayout *layout, const int &index, const
 
 void AttrScrollWidget::createLabel(QGridLayout *layout, const int &index, const QString &objName, const QDateTime &sData)
 {
-    qDebug() << "Create label for" << objName << "with datetime data";
+    qCDebug(appLog) << "Create label for" << objName << "with datetime data";
     DLabel *label = new DLabel(objName, this);
     DFontSizeManager::instance()->bind(label, DFontSizeManager::T8);
     label->setAlignment(Qt::AlignTop);
@@ -107,7 +108,7 @@ void AttrScrollWidget::createLabel(QGridLayout *layout, const int &index, const
 
 void AttrScrollWidget::createLabel(QGridLayout *layout, const int &index, const QString &objName, const bool &bData)
 {
-    qDebug() << "Create label for" << objName << "with boolean data";
+    qCDebug(appLog) << "Create label for" << objName << "with boolean data";
     DLabel *label = new DLabel(objName, this);
     DFontSizeManager::instance()->bind(label, DFontSizeManager::T8);
     label->setAlignment(Qt::AlignTop);
@@ -125,7 +126,7 @@ void AttrScrollWidget::createLabel(QGridLayout *layout, const int &index, const
 
 bool AttrScrollWidget::eventFilter(QObject *object, QEvent *event)
 {
-    qDebug() << "Event filter triggered, type:" << event->type();
+    qCDebug(appLog) << "Event filter triggered, type:" << event->type();
     if (object == this) {
         if (event->type() == QEvent::Resize) {
             QLocale locale;
@@ -146,6 +147,6 @@ bool AttrScrollWidget::eventFilter(QObject *object, QEvent *event)
         }
     }
     bool result = DFrame::eventFilter(object, event);
-    qDebug() << "Event filter processed, result:" << result;
+    qCDebug(appLog) << "Event filter processed, result:" << result;
     return result;
 }
