@@ -4,6 +4,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "BaseWidget.h"
+#include "ddlog.h"
 #include <QDebug>
 
 #include <DGuiApplicationHelper>
@@ -11,22 +12,22 @@
 BaseWidget::BaseWidget(DWidget *parent)
     : DWidget(parent)
 {
-    qDebug() << "BaseWidget created, parent:" << parent;
+    qCDebug(appLog) << "BaseWidget created, parent:" << parent;
     setAutoFillBackground(true);
     setFocusPolicy(Qt::StrongFocus);
     setContextMenuPolicy(Qt::CustomContextMenu);
-    qDebug() << "Widget theme updated";
+    qCDebug(appLog) << "Widget theme updated";
 }
 
 BaseWidget::~BaseWidget()
 {
-    qDebug() << "BaseWidget destroyed";
+    qCDebug(appLog) << "BaseWidget destroyed";
 }
 
 
 void BaseWidget::updateWidgetTheme()
 {
-    qDebug() << "Updating widget theme";
+    qCDebug(appLog) << "Updating widget theme";
     Dtk::Gui::DPalette plt = Dtk::Gui::DGuiApplicationHelper::instance()->applicationPalette();
     plt.setColor(Dtk::Gui::DPalette::Window, plt.color(Dtk::Gui::DPalette::Base));
     setPalette(plt);
@@ -34,5 +35,5 @@ void BaseWidget::updateWidgetTheme()
 
 void BaseWidget::adaptWindowSize(const double &ratio)
 {
-    qDebug() << "adaptWindowSize called with ratio:" << ratio;
+    qCDebug(appLog) << "adaptWindowSize called with ratio:" << ratio;
 }
