@@ -5,18 +5,19 @@
 
 #include "ScaleMenu.h"
 #include "DocSheet.h"
+#include "ddlog.h"
 #include <QDebug>
 
 ScaleMenu::ScaleMenu(QWidget *parent) : DMenu(parent)
 {
-    qDebug() << "ScaleMenu created, parent:" << parent;
+    qCDebug(appLog) << "ScaleMenu created, parent:" << parent;
 }
 
 void ScaleMenu::readCurDocParam(DocSheet *docSheet)
 {
-    qDebug() << "Reading document parameters";
+    qCDebug(appLog) << "Reading document parameters";
     if (docSheet == nullptr) {
-        qDebug() << "No document sheet found, return";
+        qCDebug(appLog) << "No document sheet found, return";
         return;
     }
 
@@ -49,14 +50,14 @@ void ScaleMenu::readCurDocParam(DocSheet *docSheet)
     m_pFitWorHAction->setChecked(docSheet->operation().scaleMode == Dr::FitToPageWorHMode);
     m_pFiteWAction->setChecked(docSheet->operation().scaleMode == Dr::FitToPageWidthMode);
     m_pFiteHAction->setChecked(docSheet->operation().scaleMode == Dr::FitToPageHeightMode);
-    qDebug() << "Current scale mode:" << docSheet->operation().scaleMode
+    qCDebug(appLog) << "Current scale mode:" << docSheet->operation().scaleMode
              << ", layout mode:" << docSheet->operation().layoutMode
              << ", scale factor:" << docSheet->operation().scaleFactor;
 }
 
 void ScaleMenu::onTwoPage()
 {
-    qDebug() << "Two page mode selected, checked:" << m_pTwoPageAction->isChecked();
+    qCDebug(appLog) << "Two page mode selected, checked:" << m_pTwoPageAction->isChecked();
     if (m_sheet == nullptr)
         return;
 
@@ -69,35 +70,35 @@ void ScaleMenu::onTwoPage()
 
 void ScaleMenu::onFiteH()
 {
-    qDebug() << "Fit height mode selected";
+    qCDebug(appLog) << "Fit height mode selected";
     if (m_sheet)
         m_sheet->setScaleMode(Dr::FitToPageHeightMode);
 }
 
 void ScaleMenu::onFiteW()
 {
-    qDebug() << "Fit width mode selected";
+    qCDebug(appLog) << "Fit width mode selected";
     if (m_sheet)
         m_sheet->setScaleMode(Dr::FitToPageWidthMode);
 }
 
 void ScaleMenu::onDefaultPage()
 {
-    qDebug() << "Default size (1:1) selected";
+    qCDebug(appLog) << "Default size (1:1) selected";
     if (m_sheet)
         m_sheet->setScaleMode(Dr::FitToPageDefaultMode);
 }
 
 void ScaleMenu::onFitPage()
 {
-    qDebug() << "Fit page mode selected";
+    qCDebug(appLog) << "Fit page mode selected";
     if (m_sheet)
         m_sheet->setScaleMode(Dr::FitToPageWorHMode);
 }
 
 void ScaleMenu::onScaleFactor()
 {
-    qDebug() << "Scale factor selected";
+    qCDebug(appLog) << "Scale factor selected";
     if (m_sheet == nullptr)
         return;
 
@@ -111,7 +112,7 @@ void ScaleMenu::onScaleFactor()
 
 QAction *ScaleMenu::createAction(const QString &objName, const char *member, bool checkable)
 {
-    qDebug() << "Creating action:" << objName << ", checkable:" << checkable;
+    qCDebug(appLog) << "Creating action:" << objName << ", checkable:" << checkable;
     QAction *action = new QAction(objName, this);
     action->setObjectName(objName);
     action->setCheckable(checkable);
